pub async fn evaluate(server_id: &str) -> Result<McpManagerOutput>Expand description
Fetch detailed information about a single registry server and generate a concrete install recommendation for the agent to present to the user.
pub async fn evaluate(server_id: &str) -> Result<McpManagerOutput>Fetch detailed information about a single registry server and generate a concrete install recommendation for the agent to present to the user.